@@ -35,9 +35,9 @@ class ProcessamentoImagem:
 
         if img.ndim == 3:
             img = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
-        img = cv2.fastNlMeansDenoising(img, None, 10, 9, 21)
-        img = np.array(img)
 
+        img = cv2.fastNlMeansDenoising(img, None, 5, 9)
+        img = np.array(img)
         return img
 
     def invert(self, image):
@@ -49,7 +49,8 @@ class ProcessamentoImagem:
         helpers.debug('[preprocessamento.py] binarization()')
         img = image.copy()
         img = self.invert(img)
-        img = cv2.adaptiveThreshold(img, 255, cv2.ADAPTIVE_THRESH_GAUSSIAN_C, cv2.THRESH_BINARY, 11, 2)
+        # img = cv2.adaptiveThreshold(img, 255, cv2.ADAPTIVE_THRESH_GAUSSIAN_C, cv2.THRESH_BINARY, 11, 2)
+        img = cv2.adaptiveThreshold(img, 255, cv2.ADAPTIVE_THRESH_MEAN_C , cv2.THRESH_BINARY, 9, 2)
         img = self.invert(img)
         return img
 
@@ -115,18 +116,22 @@ class ProcessamentoImagem:
             )
 
         helpers.debug('[preprocessamento.py] segmentar() | before line and sqrt processing')
-        if size_height <= 14 and size_width >= 20 and \
+        if size_height <= 15 and size_width >= 20 and \
             (any(i > 0.0000 for i in middle_height) or any(i > 0.0000 for i in middle_width)):
             # For horizontal line
-            nsize = 5 if size_height < 5 else size_height
+            nsize = 4 if size_height < 5 else size_height
+            nsize = 10 if size_height > 10 else size_height
+            print('hor ', size_height)
             new_size = tuple([int(nsize), 26])
         else:
             if size_width / size_height >= 2:
                 # For rectangle (sqrt)
                 kernel = np.ones((2,2),np.uint8)
-                image = cv2.dilate(image, kernel, iterations = 20)
-                xinit = int(width * 2 / 100)
-                xend = int(width * 65 / 100)
+                image = cv2.dilate(image, kernel, iterations = 7)
+                # xinit = int(width * 2 / 100) # validação
+                # xend = int(width * 65 / 100) # validação
+                xinit = int(width * 5 / 100)
+                xend = int(width * 85 / 100)
                 image = image[0:height, xinit:xend]
 
             new_size = size
@@ -202,7 +207,11 @@ class ProcessamentoImagem:
 
                 resized = self.redimensionar(cropped)
 
-                result_image = self._255_to_1(resized)
+                # Teste - não tinha isso na validação
+                binarized = self.binarization(resized)
+                result_image = self._255_to_1(binarized)
+
+                #result_image = self._255_to_1(resized)
 
                 attributes = {
                     'index': i,
@@ -225,7 +234,8 @@ class ProcessamentoImagem:
                 binarized = None
                 result_image = None
 
-                self.image = self.print_bounding_box(image, (_x, _y, _w, _h))
+                # self.image = self.print_bounding_box(image, (_x, _y, _w, _h))
+                self.image = image
 
             except BaseException as e:
                 print(e)
