@@ -19,9 +19,14 @@ def fit(image):
     try:
         # model = load_model('treinamento/model_all/model_16-06-2020_13-24-07.h5') # 3 > z
 
-        model = load_model(config.package_path + '/treinamento/model_all/model_21-06-2020_05-47-41.h5') 
-        # model = load_model(config.package_path + '/treinamento/model_all/model_21-06-2020_04-55-59.h5') 
-        # model = load_model(config.package_path + '/treinamento/model_all/model_17-06-2020_20-18-12.h5') 
+        # model = load_model(config.package_path + '/treinamento/model_all/model_17-06-2020_20-18-12.h5') # com = menos *
+
+        # model = load_model(config.package_path + '/treinamento/model_all/model_21-06-2020_04-55-59.h5') # sem = mais *
+        # model = load_model(config.package_path + '/treinamento/model_all/model_21-06-2020_05-47-41.h5') # sem =  mais *
+
+        model = load_model(config.package_path + '/treinamento/model_all/model_28-06-2020_21-45-32.h5') # sem =  mais *
+
+
         prediction = model.predict(image)
         index = np.argmax(prediction)
         print(index)
